@@ -1,4 +1,4 @@
-/* SPDX-FileCopyrightText: 2020-2021 Tobias Leupold <tobias.leupold@gmx.de>
+/* SPDX-FileCopyrightText: 2020-2021 Tobias Leupold <tl@l3u.de>
 
    SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-KDE-Accepted-GPL
 */
@@ -124,6 +124,16 @@ MainWindow::MainWindow(SharedObjects *sharedObjects)
 
     // "File" menu again
 
+    auto *searchMatchesAction = actionCollection()->addAction(QStringLiteral("searchMatches"));
+    searchMatchesAction->setText(i18n("Assign images to GPS data"));
+    searchMatchesAction->setIcon(QIcon::fromTheme(QStringLiteral("crosshairs")));
+    actionCollection()->setDefaultShortcut(searchMatchesAction, QKeySequence(tr("Ctrl+A")));
+    connect(searchMatchesAction, &QAction::triggered,
+            [this]
+            {
+                triggerCompleteAutomaticMatching(m_settings->defaultMatchingMode());
+            });
+
     auto *saveChangesAction = actionCollection()->addAction(QStringLiteral("saveChanges"));
     saveChangesAction->setText(i18n("Save changed images"));
     saveChangesAction->setIcon(QIcon::fromTheme(QStringLiteral("document-save-all")));
@@ -929,7 +939,9 @@ void MainWindow::triggerAutomaticMatching(ImagesListView *list, KGeoTag::SearchT
 void MainWindow::triggerCompleteAutomaticMatching(KGeoTag::SearchType searchType)
 {
     if (m_imagesModel->allImages().isEmpty()) {
-        QMessageBox::information(this, i18n("(Re)Assign all images"), i18n("Nothing to do"));
+        QMessageBox::information(this, i18n("(Re)Assign all images"),
+                                 i18n("Can't search for matches:\n"
+                                      "No images have been loaded yet."));
         return;
     }
 
@@ -946,6 +958,13 @@ void MainWindow::triggerCompleteAutomaticMatching(KGeoTag::SearchType searchType
 
 void MainWindow::matchAutomatically(const QVector<QString> &paths, KGeoTag::SearchType searchType)
 {
+    if (m_geoDataModel->rowCount() == 0) {
+        QMessageBox::information(this, i18n("Automatic matching"),
+                                 i18n("Can't search for matches:\n"
+                                      "No GPS tracks have been loaded yet."));
+        return;
+    }
+
     QApplication::setOverrideCursor(Qt::WaitCursor);
 
     m_gpxEngine->setMatchParameters(m_automaticMatchingWidget->exactMatchTolerance(),
@@ -1606,9 +1625,9 @@ void MainWindow::removeEverything()
 
 void MainWindow::centerTrackPoint(int trackIndex, int trackPointIndex)
 {
-    auto dateTime = m_geoDataModel->dateTimes().at(trackIndex).at(trackPointIndex);
+    const auto dateTime = m_geoDataModel->dateTimes().at(trackIndex).at(trackPointIndex)
+                              .toTimeZone(m_fixDriftWidget->imagesTimeZone());
     const auto coordinates = m_geoDataModel->trackPoints().at(trackIndex).value(dateTime);
-    dateTime.setTimeZone(QTimeZone(m_fixDriftWidget->imagesTimeZoneId()));
     m_mapWidget->blockSignals(true);
     m_mapWidget->centerCoordinates(coordinates);
     m_mapCenterInfo->trackPointCentered(coordinates, dateTime);
